@@ -1,3 +1,3 @@
-SA_DEFAULT_KEY = "sa_main"
+SA_DEFAULT_KEY = 'sa_main'
 
 DEFAULT_KEY = SA_DEFAULT_KEY  # synonym
